@@ -16,16 +16,27 @@
  * Boston, MA 02110-1301, USA.
  */
 
-#ifndef ACTIVITIES_CONSUMER_P_H_
-#define ACTIVITIES_CONSUMER_P_H_
+#ifndef ACTIVITIES_CONSUMER_P_H
+#define ACTIVITIES_CONSUMER_P_H
 
 #include "activitymanager_interface.h"
+#include "consumer.h"
 
 namespace KActivities {
 
-class ConsumerPrivate {
+class ConsumerPrivate: public QObject {
+    Q_OBJECT
+public:
+
+Q_SIGNALS:
+    void serviceStatusChanged(KActivities::Consumer::ServiceStatus status);
+
+public Q_SLOTS:
+    void setServicePresent(bool present);
+
 };
 
 } // namespace KActivities
 
-#endif // ACTIVITIES_CONSUMER_P_H_
+#endif // ACTIVITIES_CONSUMER_P_H
+
